Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3126)

Unified Diff: chrome/browser/renderer_host/render_process_host.h

Issue 506013: Combine ViewHostMsg_{Paint,Scroll}Rect into one IPC.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/renderer_host/render_process_host.h
===================================================================
--- chrome/browser/renderer_host/render_process_host.h (revision 34937)
+++ chrome/browser/renderer_host/render_process_host.h (working copy)
@@ -165,12 +165,12 @@
virtual void CrossSiteClosePageACK(
const ViewMsg_ClosePage_Params& params) = 0;
// Called on the UI thread to wait for the next PaintRect message for the
// specified render widget. Returns true if successful, and the msg out-
- // param will contain a copy of the received PaintRect message.
- virtual bool WaitForPaintMsg(int render_widget_id,
- const base::TimeDelta& max_delay,
- IPC::Message* msg) = 0;
+ // param will contain a copy of the received UpdateRect message.
+ virtual bool WaitForUpdateMsg(int render_widget_id,
+ const base::TimeDelta& max_delay,
+ IPC::Message* msg) = 0;
// Called when a received message cannot be decoded.
virtual void ReceivedBadMessage(uint32 msg_type) = 0;
« no previous file with comments | « chrome/browser/renderer_host/mock_render_process_host.cc ('k') | chrome/browser/renderer_host/render_widget_helper.h » ('j') | no next file with comments »
@@ -165,12 +165,12 @@
virtual void CrossSiteClosePageACK(
const ViewMsg_ClosePage_Params& params) = 0;
- // Called on the UI thread to wait for the next PaintRect message for the
+ // Called on the UI thread to wait for the next UpdateRect message for the
// specified render widget. Returns true if successful, and the msg out-

Powered by Google App Engine
This is Rietveld 408576698